==> bootstrap-annerb-1.0.4.tgz: package/gulpfile.js <==
var gulp = require('gulp')
    autoprefixer = require('gulp-autoprefixer')
    concat = require('gulp-concat')
    replace = require('gulp-replace')
    sass = require('gulp-sass');

var config = {
    autoPrefixerOptions: {
        browsers: [
            "Android 2.3",
            "Android >= 4",
            "Chrome >= 20",
            "Firefox >= 24",
            "Explorer >= 8",
            "iOS >= 6",
            "Opera >= 12",
            "Safari >= 6"
        ]
    },
    bootstrapDir: './node_modules/bootstrap-sass',
    fontAwesomeDir: './node_modules/font-awesome',
    publicDir: './public',
    sassDir: './src'
};

gulp.task('css', function () {
    return gulp.src(config.sassDir + '/*.scss')
        .pipe(sass({
            includePaths: [config.bootstrapDir + '/assets/stylesheets'],
        }))
        .pipe(autoprefixer(config.autoPrefixerOptions))
        .pipe(concat('app.css'))
        .pipe(replace('../fonts/bootstrap/', '../fonts/'))
        .pipe(gulp.dest(config.publicDir + '/css'));
});

gulp.task('fonts', function () {
    return gulp.src([
        config.bootstrapDir + '/assets/fonts/bootstrap/*',
        config.fontAwesomeDir + '/fonts/*'
    ]).pipe(gulp.dest(config.publicDir + '/fonts'));
});

gulp.task('watch', function () {
    return gulp
        .watch(config.sassDir + '/**/*.scss', ['css'])
        .on('change', function (event) {
            console.log('File ' + event.path + ' was ' + event.type + ', running tasks...');
        });
});

gulp.task('default', ['css', 'fonts', 'watch']);

==> bootstrap-annerb-1.0.6.tgz: package/gulpfile.js <==
var gulp = require('gulp')
    autoprefixer = require('gulp-autoprefixer')
    concat = require('gulp-concat')
    replace = require('gulp-replace')
    sass = require('gulp-sass');

var config = {
    autoPrefixerOptions: {
        browsers: [
            "Android 2.3",
            "Android >= 4",
            "Chrome >= 20",
            "Firefox >= 24",
            "Explorer >= 8",
            "iOS >= 6",
            "Opera >= 12",
            "Safari >= 6"
        ]
    },
    bootstrapDir: './node_modules/bootstrap-sass',
    fontAwesomeDir: './node_modules/font-awesome',
    ioniconDir: './node_modules/ionicons',
    publicDir: './public',
    sassDir: './src'
};

gulp.task('css', function () {
    return gulp.src(config.sassDir + '/*.scss')
        .pipe(sass({
            includePaths: [config.bootstrapDir + '/assets/stylesheets'],
        }))
        .pipe(autoprefixer(config.autoPrefixerOptions))
        .pipe(concat('bootstrap.css'))
        .pipe(replace('../fonts/bootstrap/', '../fonts/'))
        .pipe(gulp.dest(config.publicDir + '/css'));
});

gulp.task('fonts', function () {
    return gulp.src([
        config.bootstrapDir + '/assets/fonts/bootstrap/*',
        config.fontAwesomeDir + '/fonts/*',
        config.ioniconDir + '/dist/fonts/*'
    ]).pipe(gulp.dest(config.publicDir + '/fonts'));
});

gulp.task('watch', function () {
    return gulp
        .watch(config.sassDir + '/**/*.scss', ['css'])
        .on('change', function (event) {
            console.log('File ' + event.path + ' was ' + event.type + ', running tasks...');
        });
});

gulp.task('default', ['css', 'fonts', 'watch']);
